<?php
require_once("../class/class.conectar.php");
require_once("../class/class.usudep.php");

if(isset($_GET['esp'])){
$idesp=$_GET['esp'];
}
if(isset($_GET['tp'])){
$idtp=$_GET['tp'];
}
$idj=$_GET['idj'];
$ids=$_GET['ids'];
$tbusq=$_GET['tbusq'];
if(isset($_GET['tcont'])){
$tcont=$_GET['tcont'];
}
$nombre=$_GET['nombre'];


$Objcon = new Conectar();
$conex = $Objcon->con(); 

$Objud = new UsuarioDependencia();
$res_ud = array();

if($tbusq==1){
if($idesp!=0 and $idtp!=0 ){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp_tp($conex,$idj,$ids,$idtp,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_tp_c($conex,$idj,$ids,$idtp,$idesp,$tcont);
	}
}elseif($idesp!=0 and $idtp!=0 ){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp_tp($conex,$idj,$ids,$idtp,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_tp_c($conex,$idj,$ids,$idtp,$idesp,$tcont);
	}
}elseif($idesp==0 and $idtp!=0){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_tp($conex,$idj,$ids,$idtp);
	}else{
	$res_ud = $Objud->listar_per_dep_tp_c($conex,$idj,$ids,$idtp,$tcont);
	}
}elseif($idesp!=0 and $idtp==0){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp($conex,$idj,$ids,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_c($conex, $idj,$ids,$idesp,$tcont);
	}
}else{
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep($conex,$idj,$ids);
	}else{
	$res_ud = $Objud->listar_per_dep_c($conex,$idj,$ids,$tcont);
	}
}
}else{
	$res_ud = $Objud->listar_per_nombre($conex,$idj,$ids,$nombre);
}



$cadenalis="";
$cadenalis="<table align='center' class='FacetFormTABLE' border='1' style='border-collapse: collapse ;border-spacing:  0px;'><tr><td colspan='13'class='FacetFieldCaptionTDT' align='center' height='30'> PERSONAL ASISTENCIAL </td></tr>";
$cadenalis=$cadenalis."<tr><td class='FacetFieldCaptionTD' align='center' width='250' height='25'>APELLIDOS Y NOMBRES</td><td class='FacetFieldCaptionTD' align='center' width='130'>TIPO PERSONAL</td><td class='FacetFieldCaptionTD' align='center' width='130'>ESPECIALIDAD</td><td class='FacetFieldCaptionTD' align='center' width='130'>TIPO DE CONTRATO</td><td class='FacetFieldCaptionTD' align='center' width='100'>FECHA DE INGRESO</td><td class='FacetFieldCaptionTD' align='center' width='70'>PERIOD. LAB.</td><td class='FacetFieldCaptionTD' align='center'>EDITAR</td><td class='FacetFieldCaptionTD' align='center'>TRANSF</td><td class='FacetFieldCaptionTD' align='center'>SUSPE</td><td class='FacetFieldCaptionTD' align='center'>DesMed</td><td class='FacetFieldCaptionTD' align='center'>VACAC</td><td class='FacetFieldCaptionTD' align='center'>DATOS</td><td class='FacetFieldCaptionTD' align='center'>PROG</td></tr>";


$sumap=0;
$a=1;
$muestra="";
for ($i=0;$i<count($res_ud);$i++){
$codigo = $res_ud[$i]['cod'];
$muestra = $muestra."<input type='hidden' id='codper".$a."'  name='codper".$a."' value='".$codigo."'>";
$cadenalis=$cadenalis."<tr><td align='left'>".utf8_encode($res_ud[$i]['nombre'])."</td><td align='center'>".$res_ud[$i]['tpersona']."</td><td align='center'>".$res_ud[$i]['especialidad']."</td><td align='center'>".$res_ud[$i]['tipocontrato']."</td><td align='center'>".$res_ud[$i]['fingreso']."</td><td align='center'>".$res_ud[$i]['tiempo']."</td><td align='center'><a href='#' onClick=editarpersonal($a); ><img src='img/b_edit.png' width='17' height='17' border='0'></a></td><td align='center'><a href='#' onClick=transferirpersonal($a); ><img src='img/ver.jpg' width='17' height='17' border='0'></a></td><td align='center'><a href='#' onClick=suspenderpersonal($a); ><img src='img/b_drop.png' border='0'></a></td><td align='center'><a href='#' onClick='verdescansomedico($a)'><img src='img/heart_red.png' width='17' height='17' border='0'></a></td><td align='center'><a href='#' onClick=verdetallevacaprog($a); ><img src='img/eye.png' border='0'></a></td><td align='center'><a href='#' onClick=datospersonal($a);> <img src='img/book.png' width='17' height='17' id='person' border='0' ></a></td><td align='center'><a href='#' onClick=askprogramacion($a);> <img src='img/calendar.png' width='17' height='17' id='person' value='$codigo' border='0'></a></td></tr></tr>";
$sumap = $sumap +1;
$a=$a+1;
}
$cadenalis=$cadenalis."<tr><td colspan='13' align='center'>El numero de Personal es ".$sumap."</td></tr>";
$cadenalis=$cadenalis."</table>";
?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<link rel="stylesheet" type="text/css" href="styles/Style.css">
</head>
<body>
<?php
echo $cadenalis;echo $muestra;
?>
</body>
</html>